library modern_form_core;

import 'dart:math';
import 'dart:async';
import 'package:another_flushbar/flushbar.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_datetime_picker/flutter_datetime_picker.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:rxdart/rxdart.dart';
import 'package:share/share.dart' as share;
import 'package:modern_form_esys_flutter_share/modern_form_esys_flutter_share.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:modern_form_popupmenu/modern_form_popupmenu.dart' as menu;
import 'package:url_launcher/url_launcher.dart';
import 'package:intl/intl.dart';
import 'package:synchronized/synchronized.dart';
import 'package:flutter_keyboard_visibility/flutter_keyboard_visibility.dart';
import 'package:extended_masked_text/extended_masked_text.dart';
import 'dart:typed_data';
import 'package:cached_network_image/cached_network_image.dart';

import 'src/core/widgets/gestureDetector/mobile/ModernFormDetectorImplementation_mobile.dart'
    if (dart.library.html) 'src/core/widgets/gestureDetector/web/ModernFormDetectorImplementation_web.dart';
import 'src/core/helpers/download/mobile/download-mobile_helper.dart'
    if (dart.library.html) 'src/core/helpers/download/web/download-web_helper.dart';
import 'src/core/widgets/images/ImageWidget/network/CustomNetWorkImage_mobile.dart'
    if (dart.library.html) 'src/core/widgets/images/ImageWidget/network/CustomNetWorkImage_web.dart';
import 'src/core/widgets/images/ImageProviderWidget/network/ImageProviderWidgetNetwork_mobile.dart'
    if (dart.library.html) 'src/core/widgets/images/ImageProviderWidget/network/ImageProviderWidgetNetwork_web.dart';

part 'src/core/extensions/bool_extension.dart';
part 'src/core/extensions/date-time-range_extension.dart';
part 'src/core/extensions/duration_extension.dart';
part 'src/core/extensions/list_extension.dart';

part 'src/core/functions/colors/generateMaterialColor.dart';
part 'src/core/functions/datetime/correctFormatTime.dart';
part 'src/core/functions/datetime/joinDateWithTime.dart';
part 'src/core/functions/datetime/showModernFormDateTimePicker.dart';
part 'src/core/functions/dialogs/dialog.dart';
part 'src/core/functions/dialogs/dialogDelete.dart';
part 'src/core/functions/dialogs/dialogDeleteImage.dart';
part 'src/core/functions/dialogs/dialogError.dart';
part 'src/core/functions/edits/showMoveTo.dart';
part 'src/core/functions/edits/showOptions.dart';
part 'src/core/functions/focusnode/fieldFocusChange.dart';
part 'src/core/functions/menus/showBottomSheetCheckboxIten.dart';
part 'src/core/functions/menus/showBottomSheetProfiles.dart';
part 'src/core/functions/menus/showBottomSheetProfilesCheckBox.dart';
part 'src/core/functions/menus/showModernFormFilterPopupMenu.dart';
part 'src/core/functions/snackbar/showFlushBar.dart';

part 'src/core/helpers/global-context.dart';
part 'src/core/helpers/links_helper.dart';
part 'src/core/helpers/download/download_helper.dart';

part 'src/core/models/bottom-sheet_model.dart';
part 'src/core/models/bottom-sheet-profile_model.dart';
part 'src/core/models/file-extension-type_enum.dart';

part 'src/core/utils/modern-form-utils.dart';
part 'src/core/utils/modern-form-navigation.dart';
part 'src/core/utils/text-styles.dart';

part 'src/core/widgets/cards/ModernFormExpansionCard.dart';
part 'src/core/widgets/cards/ModernFormExpansionCardWithEdit.dart';
part 'src/core/widgets/files/ModernFormPaste.dart';
part 'src/core/widgets/files/ModernFormUpload.dart';
part 'src/core/widgets/filters/ModernFormFilterProfileIten.dart';
part 'src/core/widgets/filters/ModernFormFilterTextIten.dart';
part 'src/core/widgets/filters/ModernFormFilterTextListItens.dart';
part 'src/core/widgets/filters/ModernFormFilterTextListItensDefault.dart';
part 'src/core/widgets/filters/ModernFormFilterWithCheckboxIten.dart';
part 'src/core/widgets/gestureDetector/ModernFormDetector.dart';
part 'src/core/widgets/images/ImageWidget/ImageWidget.dart';
part 'src/core/widgets/images/ImageProviderWidget/ImageProviderWidget.dart';
part 'src/core/widgets/inputs/ModernFormBottonSheetLabel.dart';
part 'src/core/widgets/inputs/ModernFormTextsInput.dart';
part 'src/core/widgets/inputs/showModernFormInputText.dart';
part 'src/core/widgets/pickers/ModernFormBoolPicker.dart';
part 'src/core/widgets/pickers/ModernFormDatePicker.dart';
part 'src/core/widgets/pickers/ModernFormDateRangePicker.dart';
part 'src/core/widgets/pickers/ModernFormTextAndImagePicker.dart';
part 'src/core/widgets/pickers/ModernFormTextMultiPicker.dart';
part 'src/core/widgets/pickers/ModernFormTextPicker.dart';
part 'src/core/widgets/progress/ModernFormProgressDialog.dart';
part 'src/core/widgets/progress/ModernFormProgressIndicator.dart';
part 'src/core/widgets/search/ModernFormSearchAppBar.dart';
part 'src/core/widgets/search/ModernFormSearchWidget.dart';
part 'src/core/widgets/texts/ModernFormFakeTextField.dart';
part 'src/core/widgets/texts/ModernFormTextField.dart';
part 'src/core/widgets/texts/ModernFormConstrainedText.dart';
