part of modern_form_core;

Future<void> dialogError({
  required String contentText,
  required String function,
  required String path,
}) {
  String cancelButtonText = "Fechar";
  String okButtonText = "Compartilhar erro";
  String titleText = "Erro";

  Function onTapOk = () {
    if (kIsWeb) {
      Clipboard.setData(
          ClipboardData(text: 'Relatório de erros: $path ==> $contentText'));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      share.Share.share(
        'Relatório de erros: $path ==> $contentText',
        subject: "Compartilhar relatório de erro",
      );
    }
  };

  return showDialog(
    context: ModernFormGlobalContext.context!,
    builder: (BuildContext context) {
      return Container(
        width: kIsWeb ? ModernFormGlobalContext.width * .4 : null,
        child: LayoutBuilder(
          builder: (c, constraints) {
            if (Theme.of(context).platform == TargetPlatform.iOS) {
              return CupertinoAlertDialog(
                title: Text(
                  titleText,
                  style: TextStyle(fontWeight: FontWeight.w500),
                ),
                content: Text(
                    "Por favor compartilhe este relatório. Ocorreu o seguinte erro: ERROR $function ==> $contentText"),
                actions: <Widget>[
                  cancelButtonText.isNotEmpty
                      ? CupertinoDialogAction(
                          child: Text(
                            cancelButtonText,
                            style: TextStyle(
                                color: Colors.red, fontWeight: FontWeight.w600),
                          ),
                          onPressed: () {
                            Navigator.pop(context, false);
                          },
                        )
                      : Container(),
                  okButtonText.isNotEmpty
                      ? CupertinoDialogAction(
                          child: Text(
                            okButtonText,
                            style: TextStyle(
                                color: Colors.blue,
                                fontWeight: FontWeight.w600),
                          ),
                          onPressed: () {
                            onTapOk();
                          },
                        )
                      : Container(),
                ],
              );
            } else {
              return AlertDialog(
                title: Text(
                  titleText,
                  style: TextStyle(fontWeight: FontWeight.w500),
                ),
                shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(7)),
                content: Text(
                    "Por favor compartilhe este relatório. Ocorreu o seguinte erro: ERROR $function ==> $contentText"),
                actions: <Widget>[
                  cancelButtonText.isNotEmpty
                      ? TextButton(
                          child: Text(
                            cancelButtonText,
                            style: TextStyle(
                                color: Colors.red, fontWeight: FontWeight.w600),
                          ),
                          onPressed: () {
                            Navigator.pop(context, false);
                          },
                        )
                      : Container(),
                  okButtonText.isNotEmpty
                      ? TextButton(
                          child: Text(
                            okButtonText,
                            style: TextStyle(
                                color: Colors.blue,
                                fontWeight: FontWeight.w600),
                          ),
                          onPressed: () {
                            onTapOk();
                          },
                        )
                      : Container(),
                ],
              );
            }
          },
        ),
      );
    },
  );
}
