part of modern_form_core;

class ModernFormTextAndImageModel {
  final String? text;
  final String? description;
  final String? imageUrl;

  ModernFormTextAndImageModel({
    this.text = "",
    this.description = "",
    this.imageUrl = "",
  });

  ModernFormBottomSheetProfileModel get toBottonSheetProfileIten =>
      ModernFormBottomSheetProfileModel(
        imageUrl: imageUrl,
        name: text,
        description: description,
        returnValue: this,
      );

  ModernFormTextAndImageModel copyWith({
    String? text,
    String? description,
    String? imageUrl,
  }) {
    return ModernFormTextAndImageModel(
      text: text ?? this.text,
      description: description ?? this.description,
      imageUrl: imageUrl ?? this.imageUrl,
    );
  }

  Map<String, dynamic> toMap() {
    return {
      'text': text,
      'description': description,
      'imageUrl': imageUrl,
    };
  }

  factory ModernFormTextAndImageModel.fromMap(Map<String, dynamic>? map) {
    if (map == null) return ModernFormTextAndImageModel();

    return ModernFormTextAndImageModel(
      text: map['text'],
      description: map['description'],
      imageUrl: map['imageUrl'],
    );
  }

  @override
  String toString() =>
      'ModernFormTextAndImageModel(text: $text, description: $description, imageUrl: $imageUrl)';

  @override
  bool operator ==(Object o) {
    if (identical(this, o)) return true;

    return o is ModernFormTextAndImageModel &&
        o.text == text &&
        o.description == description &&
        o.imageUrl == imageUrl;
  }

  @override
  int get hashCode => text.hashCode ^ description.hashCode ^ imageUrl.hashCode;
}

class ModerFormTextAndImagePicker extends StatelessWidget {
  final void Function(ModernFormTextAndImageModel)? onChanged;
  final String? label;
  final String? helperText;
  final List<ModernFormTextAndImageModel>? suggestions;
  final bool? forceMenu;
  final ModernFormTextAndImageModel? initialValue;
  final bool? enabled;
  final String? Function(dynamic)? validator;

  const ModerFormTextAndImagePicker({
    Key? key,
    this.onChanged,
    this.label,
    this.suggestions,
    this.forceMenu,
    this.initialValue,
    this.enabled,
    this.validator,
    this.helperText,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ModernFormFakeTextField(
      label: label ?? "",
      helperText: helperText,
      validator: validator,
      isEmpty: false,
      child: ModernFormFilterProfileIten(
        label: initialValue?.text ?? "",
        subTitle: initialValue?.description ?? "",
        image: initialValue?.imageUrl ?? "",
        titleStyle: ModernFormTextStyle.moderFormTextStyle,
      ),
      enabled: enabled,
      onTap: () async {
        if (suggestions != null) {
          ModernFormTextAndImageModel? returnValue =
              await showBottomSheetProfiles(
            context,
            list: suggestions!.map((e) => e.toBottonSheetProfileIten).toList(),
            title: label,
            forceMenu: forceMenu,
          );
          if (returnValue != null && onChanged != null) {
            onChanged!(returnValue);
          }
        }
      },
    );
  }
}
