part of modern_form_core;

class ModernFormTextField extends StatefulWidget {
  final String? label;
  final TextStyle Function(TextStyle)? labelStyle;
  final String? hint;
  final TextStyle Function(TextStyle)? hintStyle;
  final String? text;
  final TextStyle Function(TextStyle)? textStyle;
  final TextStyle Function(TextStyle)? errorStyle;
  final String? helperText;
  final InputDecoration Function(InputDecoration)? decoration;
  final Widget? suffix;
  final bool enabled;
  final FocusNode? focus;
  final FocusNode? nextFocus;
  final TextInputAction? textInputAction;
  final TextInputType? keyboardType;
  final void Function()? onTap;
  final void Function(String text)? onChanged;
  final TextEditingController? controller;
  final void Function(double value)? onChangedMoney;
  final MoneyMaskedTextController? moneyController;
  final Icon? prefixIcon;
  final TextCapitalization? textCapitalization;
  final String? Function(dynamic)? validator;
  final void Function()? onFieldSubmitted;
  final bool? autofocus;

  const ModernFormTextField({
    Key? key,
    required this.label,
    this.text,
    this.suffix,
    this.enabled = true,
    this.focus,
    this.nextFocus,
    this.textInputAction,
    this.controller,
    this.onChanged,
    this.keyboardType,
    this.onTap,
    this.moneyController,
    this.onChangedMoney,
    this.hint,
    this.labelStyle,
    this.hintStyle,
    this.textStyle,
    this.prefixIcon,
    this.textCapitalization,
    this.validator,
    this.decoration,
    this.errorStyle,
    this.onFieldSubmitted,
    this.autofocus,
    this.helperText,
  }) : super(key: key);

  @override
  _ModernFormTextFieldState createState() => _ModernFormTextFieldState();
}

class _ModernFormTextFieldState extends State<ModernFormTextField> {
  final FocusNode focus = FocusNode();
  TextEditingController? controller;
  @override
  void initState() {
    KeyboardVisibilityController().onChange.listen((bool visible) {
      if (!visible) {
        focus.unfocus();
        widget.focus?.unfocus();
      }
    });

    super.initState();
  }

  // @override
  // void dispose() {
  //   focus?.dispose();
  //   widget.focus?.dispose();
  //   controller?.dispose();

  //   super.dispose();
  // }

  @override
  Widget build(BuildContext context) {
    if (widget.controller == null) {
      controller =
          TextEditingController(text: widget.text != null ? widget.text : "");
    }
    TextInputAction defaultTextInputAction = TextInputAction.next;

    if (widget.nextFocus == null) {
      defaultTextInputAction = TextInputAction.done;
    }
    InputDecoration inputDecoration = InputDecoration(
      errorText: widget.validator != null
          ? widget.validator!(widget.controller?.text ??
              widget.moneyController?.value ??
              controller?.text)
          : null,
      errorStyle: widget.errorStyle != null
          ? widget.errorStyle!(ModernFormTextStyle.moderFormErrorStyle)
          : ModernFormTextStyle.moderFormErrorStyle,
      helperText: widget.helperText,
      helperMaxLines: 9999,
      labelText: widget.label ?? "",
      labelStyle: widget.labelStyle != null
          ? widget.labelStyle!(ModernFormTextStyle.moderFormLabelStyle)
          : ModernFormTextStyle.moderFormLabelStyle,
      hintText: widget.hint ?? "",
      hintStyle: widget.hintStyle != null
          ? widget.hintStyle!(ModernFormTextStyle.moderFormHintStyle)
          : ModernFormTextStyle.moderFormHintStyle,
      suffix: widget.suffix,
      prefixIcon: widget.prefixIcon,
    );
    return TextFormField(
      controller: widget.controller ?? widget.moneyController ?? controller,
      enabled: widget.enabled,
      maxLines: null,
      autofocus: widget.autofocus ?? false,
      focusNode: widget.enabled ? widget.focus ?? focus : null,
      onFieldSubmitted: (text) {
        if (widget.nextFocus != null) {
          fieldFocusChange(context,
              currentFocus: widget.focus!, nextFocus: widget.nextFocus);
        } else {
          if (widget.onFieldSubmitted != null) {
            widget.onFieldSubmitted!();
          }
        }
      },
      textInputAction: widget.textInputAction ?? defaultTextInputAction,
      textCapitalization:
          widget.textCapitalization ?? TextCapitalization.sentences,
      keyboardType: widget.keyboardType ?? TextInputType.text,
      onChanged: (text) {
        if (widget.controller != null) {
          if (widget.onChanged != null) {
            widget.onChanged!(text);
          }
        } else if (widget.moneyController != null) {
          if (widget.onChangedMoney != null) {
            if (widget.onChangedMoney != null) {
              widget.onChangedMoney!(widget.moneyController!.numberValue);
            }
          }
        } else {
          if (widget.onChanged != null) {
            widget.onChanged!(text);
          }
        }
      },
      onEditingComplete: () {
        if (widget.focus != null) {
          widget.focus?.unfocus();
        } else {
          focus.unfocus();
        }
      },
      onTap: widget.onTap,
      decoration: widget.decoration != null
          ? widget.decoration!(inputDecoration)
          : inputDecoration,
      style: widget.textStyle != null
          ? widget.textStyle!(ModernFormTextStyle.moderFormTextStyle)
          : ModernFormTextStyle.moderFormTextStyle,
    );
  }
}
