import 'dart:io';
import 'dart:typed_data';
import 'package:file_picker/file_picker.dart';
import 'package:modern_form/modern_form_core.dart';
import 'package:open_file/open_file.dart';
import 'package:path_provider/path_provider.dart' as path;

class ModernFormFilePlatformHelper {
  static Future<Uint8List?> getFile(ModernFormFileExtensionType? type) async {
    FilePickerResult? result = await FilePicker.platform.pickFiles(
      type: FileType.custom,
      allowedExtensions: [type.toValueString],
    );

    return result?.files.single.bytes ?? null;
  }

  static Future<void> openFileWithPath(String path) async {
    OpenFile.open(path);
  }

  static Future<void> openFileWithBytes(
      List<int> bytes, String? name, String type) async {
    String appDocPath = await getApplicationDocumentsDirectory();
    final File file = File('$appDocPath/$name.$type');

    await file.writeAsBytes(bytes);
    OpenFile.open('$appDocPath/$name.$type');
  }

  static Future<String> getFilePathFromUrl(
      String url, String fileExtension) async {
    String appDocPath = await getApplicationDocumentsDirectory();

    String path = "$appDocPath/$url.$fileExtension";

    return path;
  }

  static Future<String> getApplicationDocumentsDirectory() async {
    Directory appDocDir = await path.getApplicationDocumentsDirectory();
    String appDocPath = appDocDir.path;
    return appDocPath;
  }
}
